
" Vim syntax file
" Language: DDTP files - Italian version for Server syntax
" Maintainer: Lorenzo Cappelletti <lorenzo.cappelletti@email.it>
" Last Change: 

" For copyright statement and stuff, see file ddtpCom.vim



runtime syntax/ddtpComIt.vim

syntax region ddtpSrvIt		fold keepend transparent
	\ start=/^Description-it\|^# new translation:/
	\ end=/# \(Package(s)\|packages\|changed translation\|This package\)/me=s-1
	\ contains=ddtpSrvItSynp,ddtpSrvItDesc,ddtpSrvCommServ
	\ contained

syntax match  ddtpSrvItSynp	transparent
	\ /^Description-it\(_\u\u\)\?: .*/
	\ contains=ddtpComSynpKey,ddtpComTodo,@ddtpComErrSynp,@ddtpComItErr,ddtpComErrSynpTrailingDot
	\ contained						" Synopsis

syntax region ddtpSrvItDesc 	fold keepend transparent
	\ start=/^[ #]\( new translation:\)\@!/
	\ end=/^$/
	\ contains=ddtpSrvItPara,ddtpComDot
	\ contained						" Description

syntax region ddtpSrvItPara	fold transparent
	\ start=/^[ #>][^\.]/
	\ skip=/^[#>+]/
	\ end=/ \.$/me=e-2
	\ contains=@ddtpSrvComm,ddtpComTodo,@ddtpSrvDiff,@ddtpComErrPara,@ddtpComItErr
	\ contained						" Paragraph

