augroup filetypedetect

" DDTP - server
if       getline(1) =~ '^# Package(s):' 
    \ || getline(2) =~ '^# Package(s):'
    \ || getline(2) =~ '^# Bug-Nr.:'
    \ || getline(3) =~ '^# Bug-Nr.:'
    \ || getline(1) =~ '^# packages:'
    \ || getline(2) =~ '^# packages:'
 setfiletype ddtpSrv
endif

" DDTP - client
if       getline(1) =~ '^# package:' 
    \ || getline(2) =~ '^# package:'
 setfiletype ddtpCli
endif


augroup END
